@@ -4,7 +4,7 @@ from pathlib import Path
 
 
 def get_project_root() -> Path:
-    return Path(__file__).parent
+    return Path(__file__).parent.parent
 
 PROJECT_ROOT = get_project_root()    
 
